@@ -1,4 +1,4 @@
-from app_celery_init import create_app
+from .app_celery_init import create_app
 
 # initialize app
 app = create_app()
